@@ -403,8 +403,12 @@ def getPath(cfg: Path, setting: str, default_value: str):
         fdir = os.path.expanduser(configParser['DUMMY'][setting].strip('"'))
     except:
         return None
-    if fdir.startswith(r':\'):
-        fdir = fdir.replace(':', str(cfg.parent), 1)
+    if fdir.startswith(':\\'):
+        fdir = fdir[2:]
+        #imagine a retroarch.cfg file created in windows is read in posix
+        if os.sep == '/':
+            fdir = fdir.replace('\\', '/')
+        return cfg.parent / fdir
     elif fdir == 'default':
         if default_value:
             return Path(cfg.parent,default_value)
